.. _thomson:

******************
Thomson scattering
******************

.. currentmodule:: plasmapy.diagnostics.thomson

.. automodapi:: plasmapy.diagnostics.thomson

.. nbgallery::
    :caption: Examples

    /notebooks/diagnostics/thomson
    /notebooks/diagnostics/thomson_fitting
